From 4fe23f7c072414ff1e80d3c0fa4fe6fdb5a5a21e Mon Sep 17 00:00:00 2001
From: ale <ale@incal.net>
Date: Sat, 11 Oct 2014 11:33:36 +0100
Subject: [PATCH] functions called Run should not return

---
 node/node.go | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/node/node.go b/node/node.go
index e177138c..483b8758 100644
--- a/node/node.go
+++ b/node/node.go
@@ -144,10 +144,10 @@ func (w *ConfigSyncer) updateConfigWithResponse(key, value string) {
 	}
 }
 
 // Run the ConfigSyncer in the background. It will wait for
 // initialization to complete, so that when this function returns, the
 // in-memory configuration has already been fully synchronized.
-func (w *ConfigSyncer) Run() {
+func (w *ConfigSyncer) Start() {
 	// Run until the first successful Get().
 	log.Printf("attempting to retrieve initial config...")
 	for {
@@ -280,7 +280,7 @@ func (rc *RadioNode) Run() {
 	// Bootstrap the config watcher. This ensures that we have a
 	// full configuration (thanks to the Get() call) before we
 	// start managing the icecast server.
-	rc.watcher.Run()
+	rc.watcher.Start()
 
 	// Start the presence heartbeat.
 	go rc.presence()
@@ -144,10 +144,10 @@ func (w *ConfigSyncer) updateConfigWithResponse(key, value string) {
 }
 
-// Run the ConfigSyncer in the background. It will wait for
+// Start the ConfigSyncer in the background. It will wait for
 // initialization to complete, so that when this function returns, the
 // in-memory configuration has already been fully synchronized.
-- 
GitLab